@@ -29,7 +29,9 @@ namespace Glom
 {
 
 Box_Data_List_Related::Box_Data_List_Related()
+#ifndef GLOM_ENABLE_CLIENT_ONLY
 : m_pDialogLayoutRelated(0)
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 {
   set_size_request(400, -1); //An arbitrary default.
 
@@ -42,7 +44,7 @@ Box_Data_List_Related::Box_Data_List_Related()
   m_Frame.set_label_widget(m_Label);
   m_Label.show();
 
-  m_Alignment.set_padding(6 /* top */, 0, 12 /* left */, 0);
+  m_Alignment.set_padding(Utils::DEFAULT_SPACING_SMALL /* top */, 0, Utils::DEFAULT_SPACING_LARGE /* left */, 0);
   m_Alignment.show();
 
   remove(m_AddDel);
@@ -52,6 +54,7 @@ Box_Data_List_Related::Box_Data_List_Related()
 
   m_layout_name = "list_related"; //TODO: We need a unique name when 2 portals use the same table.
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   //Delete the dialog from the base class, because we don't use it.
   if(m_pDialogLayout)
   {
@@ -59,7 +62,9 @@ Box_Data_List_Related::Box_Data_List_Related()
     delete m_pDialogLayout;
     m_pDialogLayout = 0;
   }
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "window_data_layout");
   if(refXml)
   {
@@ -73,17 +78,19 @@ Box_Data_List_Related::Box_Data_List_Related()
       m_pDialogLayoutRelated->signal_hide().connect( sigc::mem_fun(*this, &Box_Data::on_dialog_layout_hide) );
     }
   }
-
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 }
 
 Box_Data_List_Related::~Box_Data_List_Related()
 {
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   if(m_pDialogLayoutRelated)
   {
     remove_view(m_pDialogLayoutRelated);
     delete m_pDialogLayoutRelated;
     m_pDialogLayoutRelated = 0;
   }
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 }
 
 void Box_Data_List_Related::enable_buttons()
@@ -106,7 +113,7 @@ bool Box_Data_List_Related::init_db_details(const sharedptr<const LayoutItem_Por
     m_Label.set_markup(Bakery::App_Gtk::util_bold_message(relationship_title));
     m_Label.show();
 
-    m_Alignment.set_padding(6 /* top */, 0, 12 /* left */, 0);
+    m_Alignment.set_padding(Utils::DEFAULT_SPACING_SMALL /* top */, 0, Utils::DEFAULT_SPACING_LARGE /* left */, 0);
   }
   else
   {
@@ -389,6 +396,7 @@ Box_Data_List_Related::type_vecLayoutFields Box_Data_List_Related::get_fields_to
   return type_vecLayoutFields();
 }
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
 void Box_Data_List_Related::show_layout_dialog()
 {
   if(m_pDialogLayoutRelated)
@@ -397,12 +405,14 @@ void Box_Data_List_Related::show_layout_dialog()
     m_pDialogLayoutRelated->show();
   }
 }
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
 Box_Data_List_Related::type_signal_record_changed Box_Data_List_Related::signal_record_changed()
 {
   return m_signal_record_changed;
 }
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
 void Box_Data_List_Related::on_dialog_layout_hide()
 {
   m_portal = m_pDialogLayoutRelated->get_portal_layout();
@@ -420,6 +430,7 @@ void Box_Data_List_Related::on_dialog_layout_hide()
     signal_layout_changed().emit(); //TODO: Check whether it has really changed.
   }
 }
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
 void Box_Data_List_Related::on_adddel_user_requested_add()
 {
