@@ -21,6 +21,9 @@
 #include "box_data_details_find.h"
 #include <glibmm/i18n.h>
 
+namespace Glom
+{
+
 Box_Data_Details_Find::Box_Data_Details_Find()
 : Box_Data_Details(false)
 {
@@ -29,7 +32,7 @@ Box_Data_Details_Find::Box_Data_Details_Find()
   //Instead of nav buttons:
   m_HBox.pack_end(m_Button_Find, Gtk::PACK_SHRINK);
 
-  m_Button_Find.property_can_default() = true; //TODO: Make this a real method in gtkmm?
+  g_object_set(m_Button_Find.gobj(), "can-default", TRUE, (gpointer)NULL); //TODO: Make this a real method in gtkmm?
 
   show_all_children();
 }
@@ -49,7 +52,9 @@ bool Box_Data_Details_Find::fill_from_database()
 {
   Bakery::BusyCursor busy_cursor(get_app_window());
 
-  bool result = Box_DB_Table::fill_from_database();
+  const bool result = Box_DB_Table::fill_from_database();
+  if(!result)
+    return result;
 
   m_FieldsShown = get_fields_to_show();
 
@@ -101,3 +106,4 @@ Gtk::Widget* Box_Data_Details_Find::get_default_button() //override
   return &m_Button_Find;
 }
  
+} //namespace Glom
